scopus.ScopusAbstract
=====================

.. currentmodule:: scopus

.. autoclass:: ScopusAbstract

   .. rubric:: Methods

   .. autosummary::
   
      ~ScopusAbstract.get_corresponding_author_info
      
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScopusAbstract.affiliations
      ~ScopusAbstract.aggregationType
      ~ScopusAbstract.article_number
      ~ScopusAbstract.authors
      ~ScopusAbstract.bibtex
      ~ScopusAbstract.citationLanguage
      ~ScopusAbstract.citationType
      ~ScopusAbstract.citedby_count
      ~ScopusAbstract.coverDate
      ~ScopusAbstract.doi
      ~ScopusAbstract.endingPage
      ~ScopusAbstract.html
      ~ScopusAbstract.issn
      ~ScopusAbstract.issueIdentifier
      ~ScopusAbstract.latex
      ~ScopusAbstract.nauthors
      ~ScopusAbstract.pageRange
      ~ScopusAbstract.publicationName
      ~ScopusAbstract.publisher
      ~ScopusAbstract.refcount
      ~ScopusAbstract.references
      ~ScopusAbstract.ris
      ~ScopusAbstract.source_id
      ~ScopusAbstract.srctype
      ~ScopusAbstract.startingPage
      ~ScopusAbstract.subjectAreas
      ~ScopusAbstract.title
      ~ScopusAbstract.url
      ~ScopusAbstract.volume
      ~ScopusAbstract.website
